bliss: Computing automorphism groups and canonical forms of graphs
==================================================================

Description
-----------

bliss is an open source tool for computing automorphism groups and
canonical forms of graphs.

License
-------

LGPL


Upstream Contact
----------------

Bliss is currently being maintained by Tommi Junttila and Petteri Kaski.

http://www.tcs.tkk.fi/Software/bliss/index.html

We apply patches generated from https://github.com/mkoeppe/bliss (branch
apply_debian_patches) as our upstream. This tracks the patches from the
Debian package, adding an autotools build system and adjusting the
include file locations.

Dependencies
------------

None
